@@ -1,5 +1,5 @@
 ;;;; psgml-xemacs.el --- Part of SGML-editing mode with parsing support
-;; $Id: psgml-xemacs.el,v 1.6 2000/03/27 14:10:35 andreasj Exp $
+;; $Id: psgml-xemacs.el,v 2.7 2002/04/25 20:50:27 lenst Exp $
 
 ;; Copyright (C) 1994 Lennart Staflin
 
@@ -28,6 +28,8 @@
 
 ;;; Part of psgml.el
 
+;; XEmacs note: called psgml-lucid.el upstream.
+
 ;;; Menus for use with XEmacs
 
 
@@ -143,6 +145,8 @@ if the item is selected."
 ;;;; Key definitions
 
 (define-key sgml-mode-map [button3] 'sgml-tags-menu)
+;; XEmacs addition (previously in psgml-debug, upstream: psgml-other)
+(define-key sgml-mode-map [(shift button3)] 'sgml-right-menu)
 
 
 ;;;; Insert with properties
